==> qtjambi-quick-debuginfo-linux-x64-6.6.1.jar: sources/QtJambiQuick/QSGTexture_shell.h <==
#ifndef QSGTEXTURE_SHELL_H
#define QSGTEXTURE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtQuick/qsgtexture.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <QtCore/qrect.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtJambi/CoreAPI>
#include <QtJambi/RegistryAPI>


class QSGTexture_shell : public QSGTexture, public QtJambiShellInterface
{
public:
    QSGTexture_shell();
    ~QSGTexture_shell() override;

    void childEvent(QChildEvent* event0) override;
    qint64 comparisonKey() const override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    bool hasAlphaChannel() const override;
    bool hasMipmaps() const override;
    bool isAtlasTexture() const override;
    QRectF normalizedTextureSubRect() const override;
    QSize textureSize() const override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QSGTexture_access : public QSGTexture
{
    jobject __qt_nativeInterface_const_char_ptr_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jclass name0) const;
    jlong __qt_comparisonKey(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_hasAlphaChannel(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_hasMipmaps(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isAtlasTexture(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_normalizedTextureSubRect(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_textureSize(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QSGTEXTURE_SHELL_H

==> qtjambi-quick-debuginfo-linux-x64-6.7.0.jar: sources/QtJambiQuick/QSGTexture_shell.h <==
#ifndef QSGTEXTURE_SHELL_H
#define QSGTEXTURE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtQuick/qsgtexture.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <QtCore/qrect.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtJambi/CoreAPI>
#include <QtJambi/RegistryAPI>


class QSGTexture_shell : public QSGTexture, public QtJambiShellInterface
{
public:
    QSGTexture_shell();
    ~QSGTexture_shell() override;

    void childEvent(QChildEvent* event0) override;
    qint64 comparisonKey() const override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    bool hasAlphaChannel() const override;
    bool hasMipmaps() const override;
    bool isAtlasTexture() const override;
    QRectF normalizedTextureSubRect() const override;
    QSize textureSize() const override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QSGTexture_access : public QSGTexture
{
    jobject __qt_nativeInterface_const_char_ptr_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jclass name0) const;
    jlong __qt_comparisonKey_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_hasAlphaChannel_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_hasMipmaps_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isAtlasTexture_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_normalizedTextureSubRect_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_textureSize_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QSGTEXTURE_SHELL_H
